@@ -1,19 +1,17 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
 
 import os
 import itertools
 
-import pytest
 import numpy as np
+import pytest
 from astropy.io import fits
 from astropy.wcs import WCS
 from astropy_healpix import nside_to_npix
 
-from ..high_level import reproject_from_healpix, reproject_to_healpix
+from ...interpolation.tests.test_core import as_high_level_wcs
 from ...tests.test_high_level import ALL_DTYPES
-
+from ..high_level import reproject_from_healpix, reproject_to_healpix
 
 DATA = os.path.join(os.path.dirname(__file__), 'data')
 
@@ -39,10 +37,11 @@ def get_reference_header(oversample=2, nside=1):
     return reference_header
 
 
-@pytest.mark.parametrize("nside,nested,healpix_system,image_system,dtype",
-                         itertools.product([1, 2, 4, 8, 16, 32, 64], [True, False], 'C', 'C', ALL_DTYPES))
-def test_reproject_healpix_to_image_round_trip(
-        nside, nested, healpix_system, image_system, dtype):
+@pytest.mark.parametrize("wcsapi,nside,nested,healpix_system,image_system,dtype",
+                         itertools.product([True, False], [1, 2, 4, 8, 16, 32, 64],
+                                           [True, False], 'C', 'C', ALL_DTYPES))
+def test_reproject_healpix_to_image_round_trip(wcsapi, nside, nested,
+                                               healpix_system, image_system, dtype):
     """Test round-trip HEALPix->WCS->HEALPix conversion for a random map,
     with a WCS projection large enough to store each HEALPix pixel"""
 
@@ -54,6 +53,9 @@ def test_reproject_healpix_to_image_round_trip(
     wcs_out = WCS(reference_header)
     shape_out = reference_header['NAXIS2'], reference_header['NAXIS1']
 
+    if wcsapi:
+        wcs_out = as_high_level_wcs(wcs_out)
+
     image_data, footprint = reproject_from_healpix(
         (healpix_data, healpix_system), wcs_out, shape_out=shape_out,
         order='nearest-neighbor', nested=nested)
@@ -76,5 +78,6 @@ def test_reproject_file():
 def test_reproject_invalid_order():
     reference_header = get_reference_header(oversample=2, nside=8)
     with pytest.raises(ValueError) as exc:
-        reproject_from_healpix(os.path.join(DATA, 'bayestar.fits.gz'), reference_header, order='bicubic')
+        reproject_from_healpix(os.path.join(DATA, 'bayestar.fits.gz'),
+                               reference_header, order='bicubic')
     assert exc.value.args[0] == "Only nearest-neighbor and bilinear interpolation are supported"
