@@ -1,9 +1,7 @@
 import numpy as np
-
+from astropy.coordinates import ICRS, BaseCoordinateFrame, Galactic, frame_transform_graph
 from astropy.io import fits
-from astropy.io.fits import TableHDU, BinTableHDU
-from astropy.extern import six
-from astropy.coordinates import BaseCoordinateFrame, frame_transform_graph, Galactic, ICRS
+from astropy.io.fits import BinTableHDU, TableHDU
 
 FRAMES = {
     'g': Galactic(),
@@ -14,7 +12,7 @@ FRAMES = {
 def parse_coord_system(system):
     if isinstance(system, BaseCoordinateFrame):
         return system
-    elif isinstance(system, six.string_types):
+    elif isinstance(system, str):
         system = system.lower()
         if system == 'e':
             raise ValueError("Ecliptic coordinate frame not yet supported")
@@ -23,7 +21,7 @@ def parse_coord_system(system):
         else:
             system_new = frame_transform_graph.lookup_name(system)
             if system_new is None:
-                raise ValueError("Could not determine frame for system={0}".format(system))
+                raise ValueError("Could not determine frame for system={}".format(system))
             else:
                 return system_new()
 
@@ -39,8 +37,8 @@ def parse_input_healpix_data(input_data, field=0, hdu_in=None, nested=None):
         coordinate_system_in = parse_coord_system(header['COORDSYS'])
         array_in = data[data.columns[field].name].ravel()
         if 'ORDERING' in header:
-            nested = header['ORDERING'].lower()
-    elif isinstance(input_data, six.string_types):
+            nested = header['ORDERING'].lower() == 'nested'
+    elif isinstance(input_data, str):
         hdu = fits.open(input_data)[hdu_in or 1]
         return parse_input_healpix_data(hdu, field=field)
     elif isinstance(input_data, tuple) and isinstance(input_data[0], np.ndarray):
